import { NextRequest, NextResponse } from 'next/server';
import { verifyToken } from '@/lib/server-auth';
import { generateRandomToken } from '@/lib/auth';
import {
  saveResponse,
  VoteOption,
  getVoteOptions,
  getActivePolls,
  getPoll,
} from '@/lib/survey';
import { markMemberAsVoted } from '@/lib/server-auth';

export async function POST(request: NextRequest) {
  try {
    // Get the token, vote data, and poll ID from the request
    const { token, vote, comment, pollId } = await request.json();

    if (!token) {
      return NextResponse.json({ error: 'Token is required' }, { status: 400 });
    }

    // Determine which poll to use
    let targetPollId = pollId;

    // If no pollId is provided, use the first active poll (for backward compatibility)
    if (!targetPollId) {
      const activePolls = getActivePolls();
      if (activePolls.length === 0) {
        return NextResponse.json(
          { error: 'No active polls available' },
          { status: 400 }
        );
      }
      targetPollId = activePolls[0].id;
    } else {
      // Verify the poll exists
      const poll = getPoll(targetPollId);
      if (!poll) {
        return NextResponse.json({ error: 'Invalid poll ID' }, { status: 400 });
      }

      // Check if the poll is active
      if (!poll.active) {
        return NextResponse.json(
          { error: 'This poll is no longer active' },
          { status: 400 }
        );
      }
    }

    // Get available vote options for this poll
    const voteOptions = getVoteOptions(targetPollId);
    const validOptionIds = voteOptions.map(option => option.id);

    if (!vote || !validOptionIds.includes(vote)) {
      return NextResponse.json(
        { error: 'Valid vote option is required' },
        { status: 400 }
      );
    }

    // Verify the token and check if already voted in this poll
    const { valid, memberNumber, votedPolls } = await verifyToken(token);

    if (!valid) {
      return NextResponse.json({ error: 'Invalid token' }, { status: 401 });
    }

    if (votedPolls?.includes(targetPollId)) {
      return NextResponse.json(
        { error: 'Already voted in this poll' },
        { status: 400 }
      );
    }

    // Save the response with the poll ID
    const response = saveResponse(targetPollId, vote as VoteOption, comment);

    // Mark the member as voted
    if (memberNumber) {
      markMemberAsVoted(memberNumber, targetPollId);
    }

    // If token is valid, generate a new token with pollId and memberNumber
    const newToken = await generateRandomToken(memberNumber, targetPollId);

    return NextResponse.json({ success: true, response, token: newToken }); // Return new token
  } catch (error) {
    console.error('Error submitting vote:', error);
    return NextResponse.json({ error: 'Failed to submit vote' }, { status: 500 });
  }
}
