'use client';

import { useState, useEffect, Suspense } from 'react';
import { useSearchParams, useRouter } from 'next/navigation';
import Link from 'next/link';
import { EditableText } from '@/components/EditableText';
import { VoteOption, VoteOptionConfig, Poll } from '@/lib/survey';

export default function VotePage() {
  return (
    <Suspense fallback={<LoadingComponent />}>
      <VotePageContent />
    </Suspense>
  );
}

function LoadingComponent() {
  return <div>Lädt...</div>;
}

function VotePageContent() {
  const searchParams = useSearchParams();
  const router = useRouter();
  const token = searchParams.get('token');
  const pollIdParam = searchParams.get('pollId');

  const [polls, setPolls] = useState<Poll[]>([]);
  const [selectedPollId, setSelectedPollId] = useState<string | null>(null);
  const [selectedOption, setSelectedOption] = useState<VoteOption | null>(null);
  const [comment, setComment] = useState('');
  const [isLoading, setIsLoading] = useState(false);
  const [error, setError] = useState<string | null>(null);
  const [isSubmitted, setIsSubmitted] = useState(false);
  const [submittedPollIds, setSubmittedPollIds] = useState<string[]>(() => {
    if (typeof window !== 'undefined') {
      const storedPollIds = sessionStorage.getItem('submittedPollIds');
      return storedPollIds ? JSON.parse(storedPollIds) : [];
    }
    return [];
  });

  // Fetch polls
  useEffect(() => {
    const fetchPolls = async () => {
      try {
        const response = await fetch('/api/editable-text');
        if (response.ok) {
          const data = await response.json();
          if (data.texts && Array.isArray(data.texts)) {
            const pollsEntry = data.texts.find((text: { id: string }) => text.id === 'polls');

            if (pollsEntry && Array.isArray(pollsEntry.content)) {
              // Filter only active polls
              const activePolls = pollsEntry.content.filter((poll: Poll) => poll.active);
              setPolls(activePolls);

              // If a poll ID was specified in the URL, select it
              if (pollIdParam && activePolls.some((poll: Poll) => poll.id === pollIdParam)) {
                setSelectedPollId(pollIdParam);
              }
              // Otherwise select the first active poll
              else if (activePolls.length > 0) {
                setSelectedPollId(activePolls[0].id);
              }
            } else {
              // Fallback to legacy format
              const voteOptionsEntry = data.texts.find((text: { id: string }) => text.id === 'vote-options');
              const voteQuestionEntry = data.texts.find((text: { id: string }) => text.id === 'vote-question');

              if (voteOptionsEntry && Array.isArray(voteOptionsEntry.content) && voteQuestionEntry) {
                const legacyPoll: Poll = {
                  id: 'default-poll',
                  title: 'Abstimmung',
                  question: voteQuestionEntry.content,
                  options: voteOptionsEntry.content,
                  active: true,
                  createdAt: new Date().toISOString()
                };

                setPolls([legacyPoll]);
                setSelectedPollId('default-poll');
              }
            }
          }
        }
      } catch (error) {
        console.error('Error fetching polls:', error);
        // Use default poll if fetch fails
        const defaultPoll: Poll = {
          id: 'default-poll',
          title: 'Abstimmung',
          question: '<p>Stimmen Sie der vorgeschlagenen Änderung der Vereinssatzung zu?</p>',
          options: [
            { id: 'yes', label: 'Ja, ich stimme zu' },
            { id: 'no', label: 'Nein, ich stimme nicht zu' },
            { id: 'abstain', label: 'Ich enthalte mich' }
          ],
          active: true,
          createdAt: new Date().toISOString()
        };

        setPolls([defaultPoll]);
        setSelectedPollId('default-poll');
      }
    };

    fetchPolls();
  }, [pollIdParam]);

  // Redirect if no token is provided
  useEffect(() => {
    if (!token) {
      router.push('/');
    }
  }, [token, router]);

  const handlePollChange = (pollId: string) => {
    setSelectedPollId(pollId);
    setSelectedOption(null);
  };

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();

    if (!selectedPollId) {
      setError('Keine aktive Abstimmung verfügbar');
      return;
    }

    if (!selectedOption) {
      setError('Bitte wähle eine Option');
      return;
    }

    setIsLoading(true);
    setError(null);

    try {
      const response = await fetch('/api/submit-vote', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({
          token,
          pollId: selectedPollId,
          vote: selectedOption,
          comment: comment.trim() || undefined,
        }),
      });

      const data = await response.json();

      if (!response.ok) {
        throw new Error(data.error || 'Fehler beim Übermitteln der Stimme');
      }

      // Add this poll to the list of submitted polls
      setSubmittedPollIds(prev => {
        const updatedPollIds = [...prev, selectedPollId];
        sessionStorage.setItem('submittedPollIds', JSON.stringify(updatedPollIds));
        return updatedPollIds;
      });

      // If there are more polls to vote on, select the next one
      const remainingPolls = polls.filter(poll => !submittedPollIds.includes(poll.id) && poll.id !== selectedPollId);

      if (remainingPolls.length > 0) {
        setSelectedPollId(remainingPolls[0].id);
        setSelectedOption(null);
        setComment('');
      } else {
        // All polls have been voted on
        setIsSubmitted(true);
      }
    } catch (err) {
      setError(err instanceof Error ? err.message : 'Ein Fehler ist aufgetreten');
    } finally {
      setIsLoading(false);
    }
  };

  // Get the current poll
  const currentPoll = polls.find(poll => poll.id === selectedPollId);

  if (isSubmitted) {
    return (
      <div className="container mx-auto px-4 py-8">
        <div className="ssvc-main-content text-center">
          <div className="mb-6">
            <div className="w-16 h-16 bg-[#e6f0fa] flex items-center justify-center mx-auto mb-4">
              <svg xmlns="http://www.w3.org/2000/svg" className="h-8 w-8 text-[#0057a6]" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
              </svg>
            </div>
            <h2 className="text-2xl font-bold text-[#0057a6] mb-2">Vielen Dank!</h2>
            <p className="text-gray-600">
              Deine Stimme wurde erfolgreich übermittelt.
            </p>
          </div>

          <Link
            href="/"
            className="ssvc-button inline-block"
          >
            Zurück zur Startseite
          </Link>
        </div>
      </div>
    );
  }

  if (!currentPoll) {
    return (
      <div className="container mx-auto px-4 py-8">
        <div className="ssvc-main-content">
          <div className="text-center py-8">
            <h2 className="text-xl font-bold text-[#0057a6] mb-4">Keine aktive Abstimmung verfügbar</h2>
            <p className="text-gray-600 mb-6">
              Derzeit sind keine aktiven Abstimmungen verfügbar.
            </p>
            <Link
              href="/"
              className="ssvc-button inline-block"
            >
              Zurück zur Startseite
            </Link>
          </div>
        </div>
      </div>
    );
  }

  return (
    <div className="container mx-auto px-4 py-8">
      <div className="mb-8">
        <h1 className="text-2xl font-bold text-[#0057a6] mb-4">ABSTIMMUNG</h1>

        {polls.length > 1 && (
          <div className="mb-6">
            <div className="text-lg font-medium text-[#0057a6] mb-2">Wähle eine Abstimmung:</div>
            <div className="flex flex-wrap gap-2">
              {polls.map(poll => (
                <button
                  key={poll.id}
                  onClick={() => handlePollChange(poll.id)}
                  className={`px-4 py-2 rounded-md transition-colors ${selectedPollId === poll.id
                    ? 'bg-[#0057a6] text-white'
                    : submittedPollIds.includes(poll.id)
                      ? 'bg-[#e6f0fa] text-[#0057a6] border border-[#0057a6]'
                      : 'bg-gray-100 text-gray-800 hover:bg-gray-200'
                    }`}
                >
                  {poll.title}
                  {submittedPollIds.includes(poll.id) && (
                    <span className="ml-2">✓</span>
                  )}
                </button>
              ))}
            </div>
          </div>
        )}

        <div className="ssvc-main-content">
          <form onSubmit={handleSubmit} className="space-y-6">
            <div>
              <div className="text-xl font-bold text-[#0057a6] mb-4">
                <div dangerouslySetInnerHTML={{ __html: currentPoll.question }} />
              </div>

              <div className="space-y-3">
                {currentPoll.options.map((option) => (
                  <label
                    key={option.id}
                    className="flex items-center p-3 border border-gray-200 cursor-pointer hover:bg-[#e6f0fa] transition-colors"
                  >
                    <input
                      type="radio"
                      name="vote"
                      value={option.id}
                      checked={selectedOption === option.id}
                      onChange={() => setSelectedOption(option.id)}
                      className="h-5 w-5 text-[#0057a6] border-gray-300"
                    />
                    <span className="ml-3 text-gray-800">{option.label}</span>
                  </label>
                ))}
              </div>
            </div>

            <div className="p-4 bg-[#f0f7ff] border border-[#cce0ff] rounded-lg">
              <label htmlFor="comment" className="flex items-center text-base font-medium text-[#0057a6] mb-2">
                <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5 mr-2" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M7 8h10M7 12h4m1 8l-4-4H5a2 2 0 01-2-2V6a2 2 0 012-2h14a2 2 0 012 2v8a2 2 0 01-2 2h-3l-4 4z" />
                </svg>
                Kommentare oder Vorschläge (Optional)
              </label>
              <div>
                <textarea
                  id="comment"
                  name="comment"
                  rows={4}
                  value={comment}
                  onChange={(e) => setComment(e.target.value)}
                  placeholder="Dein Kommentar..."
                  className="w-full px-4 py-2 border-2 border-gray-300 rounded-md bg-[#e6f0fa] focus:outline-none focus:border-[#0057a6] focus:ring-2 focus:ring-[#0057a6]/20 transition-all duration-200 shadow-sm"
                />
              </div>
              <p className="mt-1 text-sm text-gray-500">
                Bitte kurz fassen und auf konkretes Feedback beschränken.
              </p>
            </div>

            {error && (
              <div className="text-red-500 text-sm">{error}</div>
            )}

            <button
              type="submit"
              disabled={isLoading}
              className="ssvc-button w-full disabled:opacity-50"
            >
              {isLoading ? 'Wird übermittelt...' : 'Stimme abgeben'}
            </button>
          </form>
        </div>
      </div>
    </div>
  );
}
