'use client';

import { useState } from 'react';
import { VoteOption, Poll } from '@/lib/survey';

interface Stats {
    total: number;
    [key: string]: number; // Allow dynamic keys for vote options
}

interface PollStats {
    all: Stats;
    byPoll: Record<string, Stats>;
}

interface Comment {
    vote: VoteOption;
    pollId?: string;
    comment: string;
    timestamp: string;
}

interface StatsDisplayProps {
    stats: Stats | PollStats;
    comments: Comment[];
    voteOptions: { id: string; label: string }[];
    polls?: Poll[];
    onBack: () => void;
}

export default function StatsDisplay({ stats, comments, voteOptions, polls, onBack }: StatsDisplayProps) {
    const [selectedPollId, setSelectedPollId] = useState<string | null>(null);

    // Check if we have the new stats format with byPoll
    const hasMultiplePolls = stats && 'byPoll' in stats;

    // Get the stats to display based on selection
    const getDisplayStats = (): Stats => {
        if (!hasMultiplePolls) {
            return stats as Stats;
        }

        const pollStats = stats as PollStats;

        if (selectedPollId && pollStats.byPoll[selectedPollId]) {
            return pollStats.byPoll[selectedPollId];
        }

        return pollStats.all;
    };

    // Get the comments to display based on selection
    const getDisplayComments = (): Comment[] => {
        if (!selectedPollId || !hasMultiplePolls) {
            return comments;
        }

        return comments.filter(comment => comment.pollId === selectedPollId);
    };

    // Get the options to display based on selection
    const getDisplayOptions = (): { id: string; label: string }[] => {
        if (!selectedPollId || !polls) {
            return voteOptions;
        }

        const selectedPoll = polls.find(poll => poll.id === selectedPollId);
        return selectedPoll ? selectedPoll.options : voteOptions;
    };

    const displayStats = getDisplayStats();
    const displayComments = getDisplayComments();
    const displayOptions = getDisplayOptions();

    return (
        <div className="ssvc-main-content">
            <h2 className="text-xl font-bold text-[#0057a6] mb-4">Abstimmungsstatistiken</h2>

            {/* Poll selector if multiple polls are available */}
            {hasMultiplePolls && polls && polls.length > 0 && (
                <div className="mb-6">
                    <h3 className="text-lg font-medium text-[#0057a6] mb-2">Abstimmung auswählen:</h3>
                    <div className="flex flex-wrap gap-2">
                        <button
                            onClick={() => setSelectedPollId(null)}
                            className={`px-4 py-2 rounded-md transition-colors ${selectedPollId === null
                                    ? 'bg-[#0057a6] text-white'
                                    : 'bg-gray-100 text-gray-800 hover:bg-gray-200'
                                }`}
                        >
                            Alle Abstimmungen
                        </button>
                        {polls.map(poll => (
                            <button
                                key={poll.id}
                                onClick={() => setSelectedPollId(poll.id)}
                                className={`px-4 py-2 rounded-md transition-colors ${selectedPollId === poll.id
                                        ? 'bg-[#0057a6] text-white'
                                        : 'bg-gray-100 text-gray-800 hover:bg-gray-200'
                                    }`}
                            >
                                {poll.title}
                            </button>
                        ))}
                    </div>
                </div>
            )}

            {displayStats && displayOptions.length > 0 && (
                <div className="space-y-4">
                    <div className={`grid ${displayOptions.length === 1 ? 'grid-cols-1' : displayOptions.length === 2 ? 'grid-cols-2' : 'grid-cols-3'} gap-4`}>
                        {displayOptions.map((option) => (
                            <div key={option.id} className="bg-[#e6f0fa] p-4 text-center">
                                <div className="text-2xl font-bold text-[#0057a6]">{displayStats[option.id] || 0}</div>
                                <div className="text-sm text-[#0057a6]">{option.label}</div>
                            </div>
                        ))}
                    </div>

                    <div className="bg-[#0057a6] p-4 text-center">
                        <div className="text-2xl font-bold text-white">{displayStats.total}</div>
                        <div className="text-sm text-white">Gesamtstimmen</div>
                    </div>

                    {displayStats.total > 0 && (
                        <div className="mt-4">
                            <h3 className="text-lg font-medium text-[#0057a6] mb-2">Ergebnisübersicht</h3>
                            <div className="h-6 bg-gray-200 overflow-hidden">
                                <div className="flex h-full">
                                    {displayOptions.map((option, index) => {
                                        const percentage = ((displayStats[option.id] || 0) / displayStats.total) * 100;
                                        // Define colors for different options
                                        const colors = [
                                            'bg-[#0057a6]', // Blue for first option (usually yes)
                                            'bg-red-500',    // Red for second option (usually no)
                                            'bg-gray-500'    // Gray for third option (usually abstain)
                                        ];
                                        // Use a default color for additional options
                                        const color = index < colors.length ? colors[index] : 'bg-green-500';

                                        return (
                                            <div
                                                key={option.id}
                                                className={`${color} h-full`}
                                                style={{ width: `${percentage}%` }}
                                            ></div>
                                        );
                                    })}
                                </div>
                            </div>
                            <div className="flex justify-between text-xs mt-1">
                                {displayOptions.map((option, index) => {
                                    const percentage = Math.round(((displayStats[option.id] || 0) / displayStats.total) * 100);
                                    // Define text colors for different options
                                    const textColors = [
                                        'text-[#0057a6]', // Blue for first option (usually yes)
                                        'text-red-600',    // Red for second option (usually no)
                                        'text-gray-600'    // Gray for third option (usually abstain)
                                    ];
                                    // Use a default color for additional options
                                    const textColor = index < textColors.length ? textColors[index] : 'text-green-600';

                                    return (
                                        <span key={option.id} className={textColor}>
                                            {percentage}% {option.label}
                                        </span>
                                    );
                                })}
                            </div>
                        </div>
                    )}
                </div>
            )}

            {displayComments.length > 0 && (
                <div className="mt-8">
                    <h3 className="text-lg font-medium text-[#0057a6] mb-4">Kommentare der Teilnehmer</h3>
                    <div className="space-y-4">
                        {displayComments.map((comment, index) => (
                            <div key={index} className="p-4 bg-[#e6f0fa] rounded">
                                <div className="flex justify-between items-center mb-2">
                                    <span className="font-medium">
                                        {displayOptions.find(option => option.id === comment.vote)?.label || comment.vote}
                                    </span>
                                    <span className="text-xs text-gray-500">
                                        {new Date(comment.timestamp).toLocaleDateString('de-DE')}
                                    </span>
                                </div>
                                <p className="text-gray-700">{comment.comment}</p>
                            </div>
                        ))}
                    </div>
                </div>
            )}

            <button
                onClick={onBack}
                className="ssvc-button mt-4"
            >
                Zurück zum Link-Generator
            </button>
        </div>
    );
}
