'use client';

import { useState, useRef, useEffect } from 'react';
import { Poll } from '@/lib/survey';

// Function to generate a random ID
function generateRandomId(existingIds: string[]): string {
    const characters = 'abcdefghijklmnopqrstuvwxyz0123456789';
    const length = 8;
    let result: string;

    do {
        result = '';
        for (let i = 0; i < length; i++) {
            result += characters.charAt(Math.floor(Math.random() * characters.length));
        }
    } while (existingIds.includes(result));

    return result;
}

interface VoteOptionsManagerProps {
    polls: Poll[];
    onPollsChange: (newPolls: Poll[]) => void;
}

export default function VoteOptionsManager({ polls, onPollsChange }: VoteOptionsManagerProps) {
    const [showVoteOptions, setShowVoteOptions] = useState(false);
    const [selectedPollId, setSelectedPollId] = useState<string | null>(null);
    const [newPollTitle, setNewPollTitle] = useState('');
    const [newPollQuestion, setNewPollQuestion] = useState('<p>Stimmen Sie dem Vorschlag zu?</p>');
    const [newOptionId, setNewOptionId] = useState('');
    const [newOptionLabel, setNewOptionLabel] = useState('');
    const [isLoading, setIsLoading] = useState(false);
    const [error, setError] = useState<string | null>(null);
    const [editingOptionId, setEditingOptionId] = useState<string | null>(null);
    const [editedLabel, setEditedLabel] = useState('');
    const [editingPollId, setEditingPollId] = useState<string | null>(null);
    const [editedPollTitle, setEditedPollTitle] = useState('');
    const [editedPollQuestion, setEditedPollQuestion] = useState('');
    const editInputRef = useRef<HTMLInputElement>(null);

    // Select the first poll by default
    useEffect(() => {
        if (polls.length > 0 && !selectedPollId) {
            setSelectedPollId(polls[0].id);
        }
    }, [polls, selectedPollId]);

    // Generate a random ID when the component mounts or when the form is reset
    useEffect(() => {
        if (!newOptionId && selectedPollId) {
            const currentPoll = polls.find(poll => poll.id === selectedPollId);
            if (currentPoll) {
                const existingIds = currentPoll.options.map(option => option.id);
                setNewOptionId(generateRandomId(existingIds));
            }
        }
    }, [newOptionId, selectedPollId, polls]);

    // Get the current poll
    const currentPoll = polls.find(poll => poll.id === selectedPollId);
    const voteOptions = currentPoll?.options || [];

    // Create a new poll
    const handleCreatePoll = async () => {
        if (!newPollTitle.trim()) {
            setError('Bitte geben Sie einen Titel für die neue Abstimmung ein');
            return;
        }

        setIsLoading(true);
        setError(null);

        try {
            // Generate a unique ID for the new poll
            const existingPollIds = polls.map(poll => poll.id);
            const newPollId = generateRandomId(existingPollIds);

            // Create a new poll with default options
            const newPoll: Poll = {
                id: newPollId,
                title: newPollTitle.trim(),
                question: newPollQuestion,
                options: [
                    { id: 'yes', label: 'Ja, ich stimme zu' },
                    { id: 'no', label: 'Nein, ich stimme nicht zu' },
                    { id: 'abstain', label: 'Ich enthalte mich' }
                ],
                active: true,
                createdAt: new Date().toISOString()
            };

            // Add to polls array
            const updatedPolls = [...polls, newPoll];

            // Save to server
            const response = await fetch('/api/editable-text', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    id: 'polls',
                    content: updatedPolls
                }),
            });

            if (!response.ok) {
                throw new Error('Fehler beim Speichern der neuen Abstimmung');
            }

            // Update parent component state
            onPollsChange(updatedPolls);

            // Select the new poll
            setSelectedPollId(newPollId);

            // Reset form
            setNewPollTitle('');
            setNewPollQuestion('<p>Stimmen Sie dem Vorschlag zu?</p>');
        } catch (err) {
            setError(err instanceof Error ? err.message : 'Ein Fehler ist aufgetreten');
        } finally {
            setIsLoading(false);
        }
    };

    // Toggle poll active status
    const handleTogglePollActive = async (pollId: string) => {
        setIsLoading(true);
        setError(null);

        try {
            // Update in local state
            const updatedPolls = polls.map(poll =>
                poll.id === pollId
                    ? { ...poll, active: !poll.active }
                    : poll
            );

            // Save to server
            const response = await fetch('/api/editable-text', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    id: 'polls',
                    content: updatedPolls
                }),
            });

            if (!response.ok) {
                throw new Error('Fehler beim Aktualisieren des Abstimmungsstatus');
            }

            // Update parent component state
            onPollsChange(updatedPolls);
        } catch (err) {
            setError(err instanceof Error ? err.message : 'Ein Fehler ist aufgetreten');
        } finally {
            setIsLoading(false);
        }
    };

    // Delete a poll
    const handleDeletePoll = async (pollId: string) => {
        // Show confirmation dialog
        const pollToDelete = polls.find(poll => poll.id === pollId);
        if (!confirm(`Sind Sie sicher, dass Sie die Abstimmung "${pollToDelete?.title}" löschen möchten? Alle zugehörigen Abstimmungsdaten werden gelöscht.`)) {
            return;
        }

        setIsLoading(true);
        setError(null);

        try {
            // Remove from local state
            const updatedPolls = polls.filter(poll => poll.id !== pollId);

            // Save to server
            const response = await fetch('/api/editable-text', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    id: 'polls',
                    content: updatedPolls
                }),
            });

            if (!response.ok) {
                throw new Error('Fehler beim Löschen der Abstimmung');
            }

            // Update parent component state
            onPollsChange(updatedPolls);

            // If the deleted poll was selected, select another one
            if (selectedPollId === pollId) {
                setSelectedPollId(updatedPolls.length > 0 ? updatedPolls[0].id : null);
            }
        } catch (err) {
            setError(err instanceof Error ? err.message : 'Ein Fehler ist aufgetreten');
        } finally {
            setIsLoading(false);
        }
    };

    // Add a new vote option to the current poll
    const handleAddVoteOption = async () => {
        if (!selectedPollId) {
            setError('Bitte wählen Sie zuerst eine Abstimmung aus');
            return;
        }

        if (!newOptionId || !newOptionLabel) {
            setError('Bitte geben Sie sowohl eine ID als auch ein Label für die neue Option ein');
            return;
        }

        // Check if ID already exists in the current poll
        if (currentPoll && currentPoll.options.some(option => option.id === newOptionId)) {
            setError('Eine Option mit dieser ID existiert bereits in dieser Abstimmung');
            return;
        }

        setIsLoading(true);
        setError(null);

        try {
            // Update the current poll with the new option
            const updatedPolls = polls.map(poll => {
                if (poll.id === selectedPollId) {
                    return {
                        ...poll,
                        options: [...poll.options, { id: newOptionId, label: newOptionLabel }]
                    };
                }
                return poll;
            });

            // Save to server
            const response = await fetch('/api/editable-text', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    id: 'polls',
                    content: updatedPolls
                }),
            });

            if (!response.ok) {
                throw new Error('Fehler beim Speichern der Abstimmungsoptionen');
            }

            // Update parent component state
            onPollsChange(updatedPolls);

            // Reset form and generate a new random ID
            setNewOptionLabel('');
            if (currentPoll) {
                const existingIds = currentPoll.options.map(option => option.id);
                setNewOptionId(generateRandomId(existingIds));
            }
        } catch (err) {
            setError(err instanceof Error ? err.message : 'Ein Fehler ist aufgetreten');
        } finally {
            setIsLoading(false);
        }
    };

    // Remove a vote option
    const handleRemoveVoteOption = async (optionId: string) => {
        if (!selectedPollId) return;

        // Don't allow removing if there are less than 2 options
        if (voteOptions.length <= 1) {
            setError('Es muss mindestens eine Abstimmungsoption vorhanden sein');
            return;
        }

        // Show confirmation dialog
        const optionToRemove = voteOptions.find(option => option.id === optionId);
        if (!confirm(`Sind Sie sicher, dass Sie die Option "${optionToRemove?.label}" entfernen möchten? Bestehende Abstimmungen mit dieser Option werden nicht gelöscht, aber in den Statistiken möglicherweise nicht mehr korrekt angezeigt.`)) {
            return;
        }

        setIsLoading(true);
        setError(null);

        try {
            // Update the current poll with the option removed
            const updatedPolls = polls.map(poll => {
                if (poll.id === selectedPollId) {
                    return {
                        ...poll,
                        options: poll.options.filter(option => option.id !== optionId)
                    };
                }
                return poll;
            });

            // Save to server
            const response = await fetch('/api/editable-text', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    id: 'polls',
                    content: updatedPolls
                }),
            });

            if (!response.ok) {
                throw new Error('Fehler beim Speichern der Abstimmungsoptionen');
            }

            // Update parent component state
            onPollsChange(updatedPolls);
        } catch (err) {
            setError(err instanceof Error ? err.message : 'Ein Fehler ist aufgetreten');
        } finally {
            setIsLoading(false);
        }
    };

    return (
        <div className="mb-6">
            <div className="flex justify-between items-center mb-4">
                <h2 className="text-xl font-bold text-[#0057a6]">Abstimmungen verwalten</h2>
                <button
                    onClick={() => setShowVoteOptions(!showVoteOptions)}
                    className="text-sm text-[#0057a6] hover:underline"
                >
                    {showVoteOptions ? 'Ausblenden' : 'Bearbeiten'}
                </button>
            </div>

            {showVoteOptions && (
                <div className="bg-[#e6f0fa] p-4 mb-4">
                    {/* Poll selection */}
                    <div className="mb-6">
                        <h3 className="font-medium text-[#0057a6] mb-3">Abstimmungen</h3>

                        <div className="space-y-2 mb-4">
                            {polls.map(poll => (
                                <div key={poll.id} className="flex items-center justify-between p-3 bg-white">
                                    <div className="flex-1">
                                        <div className="font-medium">{poll.title}</div>
                                        <div className="text-sm text-gray-500">
                                            ID: {poll.id} | Status: {poll.active ? 'Aktiv' : 'Inaktiv'} |
                                            Erstellt: {new Date(poll.createdAt).toLocaleDateString()}
                                        </div>
                                    </div>
                                    <div className="flex space-x-2">
                                        <button
                                            onClick={() => setSelectedPollId(poll.id)}
                                            className={`px-2 py-1 text-sm rounded ${selectedPollId === poll.id
                                                ? 'bg-[#0057a6] text-white'
                                                : 'bg-gray-100 text-gray-800 hover:bg-gray-200'
                                                }`}
                                            title="Diese Abstimmung bearbeiten"
                                        >
                                            Bearbeiten
                                        </button>
                                        <button
                                            onClick={() => handleTogglePollActive(poll.id)}
                                            className={`px-2 py-1 text-sm rounded ${poll.active
                                                ? 'bg-green-100 text-green-800 hover:bg-green-200'
                                                : 'bg-gray-100 text-gray-800 hover:bg-gray-200'
                                                }`}
                                            title={poll.active ? 'Abstimmung deaktivieren' : 'Abstimmung aktivieren'}
                                        >
                                            {poll.active ? 'Aktiv' : 'Inaktiv'}
                                        </button>
                                        <button
                                            onClick={() => handleDeletePoll(poll.id)}
                                            className="text-red-600 hover:text-red-800"
                                            title="Abstimmung löschen"
                                        >
                                            ✕
                                        </button>
                                    </div>
                                </div>
                            ))}
                        </div>

                        {/* Create new poll form */}
                        <div className="p-3 bg-white mb-4">
                            <h4 className="font-medium text-[#0057a6] mb-2">Neue Abstimmung erstellen</h4>
                            <div className="space-y-3">
                                <div>
                                    <label htmlFor="newPollTitle" className="block text-sm font-medium text-gray-700 mb-1">
                                        Titel
                                    </label>
                                    <input
                                        type="text"
                                        id="newPollTitle"
                                        value={newPollTitle}
                                        onChange={(e) => setNewPollTitle(e.target.value)}
                                        className="w-full px-3 py-2 border border-gray-300 focus:outline-none focus:border-[#0057a6]"
                                        placeholder="Titel der Abstimmung"
                                    />
                                </div>
                                <div>
                                    <label htmlFor="newPollQuestion" className="block text-sm font-medium text-gray-700 mb-1">
                                        Frage
                                    </label>
                                    <textarea
                                        id="newPollQuestion"
                                        value={newPollQuestion}
                                        onChange={(e) => setNewPollQuestion(e.target.value)}
                                        className="w-full px-3 py-2 border border-gray-300 focus:outline-none focus:border-[#0057a6]"
                                        placeholder="Frage der Abstimmung"
                                        rows={3}
                                    />
                                    <p className="text-xs text-gray-500 mt-1">
                                        HTML-Tags wie &lt;p&gt; sind erlaubt.
                                    </p>
                                </div>
                                <button
                                    onClick={handleCreatePoll}
                                    disabled={isLoading}
                                    className="ssvc-button w-full disabled:opacity-50"
                                >
                                    {isLoading ? 'Wird erstellt...' : 'Abstimmung erstellen'}
                                </button>
                            </div>
                        </div>
                    </div>

                    {/* Vote options section */}
                    {selectedPollId && currentPoll && (
                        <div>
                            <h3 className="font-medium text-[#0057a6] mb-3">
                                Abstimmungsoptionen für "{currentPoll.title}"
                            </h3>

                            <div className="space-y-2 mb-4">
                                {voteOptions.map((option) => (
                                    <div key={option.id} className="flex items-center justify-between p-2 bg-white">
                                        <div>
                                            <span className="font-medium">{option.id}:</span> {option.label}
                                        </div>
                                        <button
                                            onClick={() => handleRemoveVoteOption(option.id)}
                                            className="text-red-600 hover:text-red-800"
                                            title="Option entfernen"
                                        >
                                            ✕
                                        </button>
                                    </div>
                                ))}
                            </div>

                            <div className="p-3 bg-white">
                                <h4 className="font-medium text-[#0057a6] mb-2">Neue Option hinzufügen</h4>
                                <div className="space-y-3">
                                    <div>
                                        <label htmlFor="newOptionId" className="block text-sm font-medium text-gray-700 mb-1">
                                            Option ID
                                        </label>
                                        <input
                                            type="text"
                                            id="newOptionId"
                                            value={newOptionId}
                                            onChange={(e) => setNewOptionId(e.target.value)}
                                            className="w-full px-3 py-2 border border-gray-300 focus:outline-none focus:border-[#0057a6]"
                                            placeholder="option-id"
                                        />
                                    </div>
                                    <div>
                                        <label htmlFor="newOptionLabel" className="block text-sm font-medium text-gray-700 mb-1">
                                            Anzeigename
                                        </label>
                                        <input
                                            type="text"
                                            id="newOptionLabel"
                                            value={newOptionLabel}
                                            onChange={(e) => setNewOptionLabel(e.target.value)}
                                            className="w-full px-3 py-2 border border-gray-300 focus:outline-none focus:border-[#0057a6]"
                                            placeholder="Anzeigename der Option"
                                        />
                                    </div>
                                    {error && (
                                        <div className="text-red-500 text-sm">{error}</div>
                                    )}
                                    <button
                                        onClick={handleAddVoteOption}
                                        disabled={isLoading}
                                        className="ssvc-button w-full disabled:opacity-50"
                                    >
                                        {isLoading ? 'Wird hinzugefügt...' : 'Option hinzufügen'}
                                    </button>
                                </div>
                            </div>
                        </div>
                    )}
                </div>
            )}
        </div>
    );
}
