import { SignJWT } from 'jose';
import { v4 as uuidv4 } from 'uuid';
import bcrypt from 'bcryptjs';
import { getMemberCredentials } from './server-auth';

// Interface for member credentials
export interface MemberCredential {
  memberNumber: string;
  password: string;
  votedPolls: string[]; // Track polls the member has voted in
  lastLogin?: string;
}

// Generate a one-time use token for voting
export async function generateRandomToken(memberNumber?: string, pollId?: string): Promise<string> {
  // This function is used in API routes
  const tokenId = uuidv4();
  type Payload = { tokenId: string; memberNumber?: string; pollId?: string; votedPolls?: string[] };
  const payload: Payload = { tokenId };

  // If memberNumber is provided, include it in the token
  if (memberNumber) {
    payload.memberNumber = memberNumber;

    // Fetch the member's votedPolls from the member_credentials.json file
    const members = getMemberCredentials();
    const member = members.find(m => m.memberNumber === memberNumber);
    if (member) {
      // Add the pollId to the member's votedPolls if not already present
      if (pollId && !member.votedPolls.includes(pollId)) {
        member.votedPolls.push(pollId);
      }
      payload.votedPolls = member.votedPolls;
    }
  }

  // Include pollId in the payload
  if (pollId) {
    payload.pollId = pollId;
  }

  // Use a secret key from environment variable or a default one
  const secretKey =
    process.env.JWT_SECRET_KEY ||
    'schafwaschener-segelverein-secret-key-for-jwt-signing';
  const encoder = new TextEncoder();
  const key = encoder.encode(secretKey);

  const token = await new SignJWT(payload)
    .setProtectedHeader({ alg: 'HS256' })
    .setIssuedAt()
    .setExpirationTime('7d') // Token expires in 7 days
    .sign(key);

  return token;
}

// Hash a password
export function hashPassword(password: string): string {
  return bcrypt.hashSync(password, 10);
}

// Compare a password with a hash
export function comparePassword(password: string, hash: string): boolean {
  return bcrypt.compareSync(password, hash);
}
