import fs from 'fs';
import path from 'path';
import { v4 as uuidv4 } from 'uuid';

// Define the vote option interface
export interface VoteOptionConfig {
  id: string;
  label: string;
}

// Define the poll interface
export interface Poll {
  id: string;
  title: string;
  question: string;
  options: VoteOptionConfig[];
  active: boolean;
  createdAt: string;
}

// Define the survey response type
export type VoteOption = string; // Now a string that matches the option id

export interface SurveyResponse {
  id: string; // Used only for internal tracking, not associated with the voter
  pollId: string; // ID of the poll this response is for
  vote: VoteOption;
  comment?: string;
  timestamp: string;
}

// Path to the data files
const DATA_FILE = path.join(process.cwd(), 'data', 'responses.json');
const TEXT_FILE = path.join(process.cwd(), 'data', 'editable_text.json');

// Ensure the data directory exists
function ensureDataDirectory() {
  const dataDir = path.join(process.cwd(), 'data');
  if (!fs.existsSync(dataDir)) {
    fs.mkdirSync(dataDir, { recursive: true });
  }
}

// Get all polls from editable_text.json
export function getPolls(): Poll[] {
  ensureDataDirectory();

  if (!fs.existsSync(TEXT_FILE)) {
    // Default poll if file doesn't exist
    return [
      {
        id: 'default-poll',
        title: 'Default Poll',
        question: '<p>Stimmen Sie der vorgeschlagenen Änderung der Vereinssatzung zu?</p>',
        options: [
          { id: 'yes', label: 'Ja, ich stimme zu' },
          { id: 'no', label: 'Nein, ich stimme nicht zu' },
          { id: 'abstain', label: 'Ich enthalte mich' }
        ],
        active: true,
        createdAt: new Date().toISOString()
      }
    ];
  }

  try {
    const data = fs.readFileSync(TEXT_FILE, 'utf-8');
    const texts = JSON.parse(data);

    const pollsEntry = texts.find((text: { id: string }) => text.id === 'polls');

    if (pollsEntry && Array.isArray(pollsEntry.content)) {
      return pollsEntry.content;
    }

    // If polls entry doesn't exist, create a default poll from the legacy format
    const voteOptionsEntry = texts.find((text: { id: string }) => text.id === 'vote-options');
    const voteQuestionEntry = texts.find((text: { id: string }) => text.id === 'vote-question');

    if (voteOptionsEntry && Array.isArray(voteOptionsEntry.content) && voteQuestionEntry) {
      return [
        {
          id: 'default-poll',
          title: 'Default Poll',
          question: voteQuestionEntry.content,
          options: voteOptionsEntry.content,
          active: true,
          createdAt: new Date().toISOString()
        }
      ];
    }

    // Return default poll if not found or invalid
    return [
      {
        id: 'default-poll',
        title: 'Default Poll',
        question: '<p>Stimmen Sie der vorgeschlagenen Änderung der Vereinssatzung zu?</p>',
        options: [
          { id: 'yes', label: 'Ja, ich stimme zu' },
          { id: 'no', label: 'Nein, ich stimme nicht zu' },
          { id: 'abstain', label: 'Ich enthalte mich' }
        ],
        active: true,
        createdAt: new Date().toISOString()
      }
    ];
  } catch (error) {
    console.error('Error reading polls:', error);
    // Return default poll on error
    return [
      {
        id: 'default-poll',
        title: 'Default Poll',
        question: '<p>Stimmen Sie der vorgeschlagenen Änderung der Vereinssatzung zu?</p>',
        options: [
          { id: 'yes', label: 'Ja, ich stimme zu' },
          { id: 'no', label: 'Nein, ich stimme nicht zu' },
          { id: 'abstain', label: 'Ich enthalte mich' }
        ],
        active: true,
        createdAt: new Date().toISOString()
      }
    ];
  }
}

// Get a specific poll by ID
export function getPoll(pollId: string): Poll | null {
  const polls = getPolls();
  return polls.find(poll => poll.id === pollId) || null;
}

// Get active polls
export function getActivePolls(): Poll[] {
  const polls = getPolls();
  return polls.filter(poll => poll.active);
}

// Get vote options for a specific poll
export function getVoteOptions(pollId?: string): VoteOptionConfig[] {
  if (pollId) {
    const poll = getPoll(pollId);
    if (poll) {
      return poll.options;
    }
  }

  // For backward compatibility, get the first active poll's options
  const activePolls = getActivePolls();
  if (activePolls.length > 0) {
    return activePolls[0].options;
  }

  // Fallback to legacy format
  ensureDataDirectory();

  if (!fs.existsSync(TEXT_FILE)) {
    // Default options if file doesn't exist
    return [
      { id: 'yes', label: 'Ja, ich stimme zu' },
      { id: 'no', label: 'Nein, ich stimme nicht zu' },
      { id: 'abstain', label: 'Ich enthalte mich' }
    ];
  }

  try {
    const data = fs.readFileSync(TEXT_FILE, 'utf-8');
    const texts = JSON.parse(data);

    const voteOptionsEntry = texts.find((text: { id: string }) => text.id === 'vote-options');

    if (voteOptionsEntry && Array.isArray(voteOptionsEntry.content)) {
      return voteOptionsEntry.content;
    }

    // Return default options if not found or invalid
    return [
      { id: 'yes', label: 'Ja, ich stimme zu' },
      { id: 'no', label: 'Nein, ich stimme nicht zu' },
      { id: 'abstain', label: 'Ich enthalte mich' }
    ];
  } catch (error) {
    console.error('Error reading vote options:', error);
    // Return default options on error
    return [
      { id: 'yes', label: 'Ja, ich stimme zu' },
      { id: 'no', label: 'Nein, ich stimme nicht zu' },
      { id: 'abstain', label: 'Ich enthalte mich' }
    ];
  }
}

// Get all survey responses
export function getAllResponses(): SurveyResponse[] {
  ensureDataDirectory();

  if (!fs.existsSync(DATA_FILE)) {
    return [];
  }

  const data = fs.readFileSync(DATA_FILE, 'utf-8');
  return JSON.parse(data);
}

// Get responses for a specific poll
export function getPollResponses(pollId: string): SurveyResponse[] {
  const responses = getAllResponses();
  return responses.filter(response => response.pollId === pollId);
}

// Save a new survey response
export function saveResponse(pollId: string, vote: VoteOption, comment?: string): SurveyResponse {
  const responses = getAllResponses();

  // Create a new response with a random ID (not associated with the voter)
  const newResponse: SurveyResponse = {
    id: uuidv4(), // Random ID only for internal tracking
    pollId,
    vote,
    comment,
    timestamp: new Date().toISOString(),
  };

  responses.push(newResponse);

  ensureDataDirectory();
  fs.writeFileSync(DATA_FILE, JSON.stringify(responses, null, 2));

  return newResponse;
}

// Get survey statistics for all polls
export function getSurveyStats() {
  const responses = getAllResponses();
  const polls = getPolls();

  // Create stats for each poll
  const pollStats: Record<string, Record<string, number>> = {};

  // Initialize stats for each poll
  polls.forEach(poll => {
    const pollResponses = responses.filter(response => response.pollId === poll.id);

    // Initialize stats object with total count
    const stats: Record<string, number> = {
      total: pollResponses.length
    };

    // Initialize count for each vote option
    poll.options.forEach(option => {
      stats[option.id] = 0;
    });

    // Count votes for each option
    pollResponses.forEach(response => {
      if (stats[response.vote] !== undefined) {
        stats[response.vote]++;
      }
    });

    pollStats[poll.id] = stats;
  });

  // For backward compatibility, also return stats for all responses combined
  const allStats: Record<string, number> = {
    total: responses.length
  };

  // Get all unique option IDs across all polls
  const allOptionIds = new Set<string>();
  polls.forEach(poll => {
    poll.options.forEach(option => {
      allOptionIds.add(option.id);
    });
  });

  // Initialize count for each vote option
  Array.from(allOptionIds).forEach(optionId => {
    allStats[optionId] = 0;
  });

  // Count votes for each option
  responses.forEach(response => {
    if (allStats[response.vote] !== undefined) {
      allStats[response.vote]++;
    }
  });

  return {
    all: allStats,
    byPoll: pollStats
  };
}

// Get survey statistics for a specific poll
export function getPollStats(pollId: string) {
  const responses = getPollResponses(pollId);
  const poll = getPoll(pollId);

  if (!poll) {
    return null;
  }

  // Initialize stats object with total count
  const stats: Record<string, number> = {
    total: responses.length
  };

  // Initialize count for each vote option
  poll.options.forEach(option => {
    stats[option.id] = 0;
  });

  // Count votes for each option
  responses.forEach(response => {
    if (stats[response.vote] !== undefined) {
      stats[response.vote]++;
    }
  });

  return stats;
}
